@@ -3,6 +3,7 @@ from typing import List, Optional, Any
 from dataclasses import dataclass, field
 from dataclasses_json import dataclass_json, config
 from ..utils import to_dict
+from ..exception import RPCException
 
 
 @dataclass_json
@@ -158,7 +159,9 @@ class Txpool:
 
         Please note, there may be multiple transactions associated with the same account and nonce
          This can happen if the user broadcast mutliple ones with varying gas allowances (or even complerely different transactions)
-        :return transactionObject: The return transaction object
+        #### Returns #ContentResponseTransactionObject
+
+        transactionObject: The return transaction object
         """
         json_data = {
             "method": "txpool_content",
@@ -167,6 +170,9 @@ class Txpool:
             "id": 1
         }
         response = requests.post(self.url, json=to_dict(json_data))
+        error = response.json().get("error")
+        if error:
+            raise RPCException(error["message"])
         return ContentResponseTransactionObject.from_dict(
             response.json()["result"])
 
@@ -181,7 +187,9 @@ class Txpool:
 
         Please note, there may be multiple transactions associated with the same account and nonce
          This can happen if the user broadcast mutliple ones with varying gas allowances (or even complerely different transactions)
-        :return transactionObject: the return transcation object
+        #### Returns #InspectResponseTransactionObject
+
+        transactionObject: the return transcation object
         """
         json_data = {
             "method": "txpool_inspect",
@@ -190,6 +198,9 @@ class Txpool:
             "id": 1
         }
         response = requests.post(self.url, json=to_dict(json_data))
+        error = response.json().get("error")
+        if error:
+            raise RPCException(error["message"])
         return InspectResponseTransactionObject.from_dict(
             response.json()["result"])
 
@@ -198,7 +209,9 @@ class Txpool:
         The status inspection property can be queried for the number of transactions currently pending for inclusion in the next block(s), as well as the ones that are being scheduled for future execution only
 
         The result is an object with two fields pending and queued, each of which is a counter representing the number of transactions in that particular state
-        :return statusObject: An object containing transaction status
+        #### Returns #StatusResponseStatusObject
+
+        statusObject: An object containing transaction status
         """
         json_data = {
             "method": "txpool_status",
@@ -207,4 +220,7 @@ class Txpool:
             "id": 1
         }
         response = requests.post(self.url, json=to_dict(json_data))
+        error = response.json().get("error")
+        if error:
+            raise RPCException(error["message"])
         return StatusResponseStatusObject.from_dict(response.json()["result"])
